pub struct AnimStack {
animations: Vec<AnimationCell>,
duration_secs: f64,
}Expand description
Dynamic overlay animation container.
Unlike AnimSequence, every pushed animation keeps its own local start
time and the stack duration is the maximum child extent.
Fields
animations: Vec<AnimationCell>duration_secs: f64Implementations
Sourceimpl AnimStack
impl AnimStack
Sourcepub fn push<A>(&mut self, animation: A) -> &mut AnimStackwhere
A: Animation + 'static,
pub fn push<A>(&mut self, animation: A) -> &mut AnimStackwhere
A: Animation + 'static,
Add an animation without advancing the other children.
Sourcepub fn extend(&mut self, stack: AnimStack) -> &mut AnimStack
pub fn extend(&mut self, stack: AnimStack) -> &mut AnimStack
Add all direct child animations from another dynamic stack.
Sourcepub fn duration_secs(&self) -> f64
pub fn duration_secs(&self) -> f64
Current maximum child extent.
Sourcepub fn built_animations(&self) -> &[AnimationCell]
pub fn built_animations(&self) -> &[AnimationCell]
Borrow the direct child animations in local stack coordinates.
Sourcepub fn into_built_animations(self) -> Vec<AnimationCell>
pub fn into_built_animations(self) -> Vec<AnimationCell>
Consume this stack into its direct child animations.