pub struct RanimScene {
pub(crate) timelines: Vec<Timeline>,
pub(crate) time_marks: Vec<(f64, TimeMark)>,
}Expand description
The main struct that offers the ranim’s API, and encodes animations
Fields
timelines: Vec<Timeline>time_marks: Vec<(f64, TimeMark)>Implementations
Sourceimpl RanimScene
impl RanimScene
Sourcepub fn seal(self) -> SealedRanimScene
pub fn seal(self) -> SealedRanimScene
Seals the scene to SealedRanimScene.
Sourcepub fn new() -> RanimScene
pub fn new() -> RanimScene
Create a new RanimScene
Sourcepub fn insert_empty(&mut self) -> TimelineId
pub fn insert_empty(&mut self) -> TimelineId
Insert an empty timeline.
Sourcepub fn insert_empty_at(&mut self, sec: f64) -> TimelineId
pub fn insert_empty_at(&mut self, sec: f64) -> TimelineId
Insert an empty timeline and forward it to the given sec.
Sourcepub fn insert<T>(&mut self, item: T) -> TimelineId
pub fn insert<T>(&mut self, item: T) -> TimelineId
Insert a timeline at 0.0 sec and play StaticAnim::show on it.
Sourcepub fn insert_at<T>(&mut self, item: T, sec: f64) -> TimelineId
pub fn insert_at<T>(&mut self, item: T, sec: f64) -> TimelineId
Insert a timeline at the given sec and play StaticAnim::show on it.
Sourcepub fn insert_with(&mut self, f: impl FnMut(&mut Timeline)) -> TimelineId
pub fn insert_with(&mut self, f: impl FnMut(&mut Timeline)) -> TimelineId
Insert a empty timeline and call f on it.
Sourcepub fn timelines_mut(&mut self) -> &mut [Timeline]
pub fn timelines_mut(&mut self) -> &mut [Timeline]
Get mutable reference of all timelines
Sourcepub fn timeline<'a, T>(
&'a self,
index: T,
) -> <T as TimelineIndex<'a>>::RefOutputwhere
T: TimelineIndex<'a>,
pub fn timeline<'a, T>(
&'a self,
index: T,
) -> <T as TimelineIndex<'a>>::RefOutputwhere
T: TimelineIndex<'a>,
Get the reference of timeline(s) by the TimelineIndex.
Sourcepub fn timeline_mut<'a, T>(
&'a mut self,
index: T,
) -> <T as TimelineIndex<'a>>::MutOutputwhere
T: TimelineIndex<'a>,
pub fn timeline_mut<'a, T>(
&'a mut self,
index: T,
) -> <T as TimelineIndex<'a>>::MutOutputwhere
T: TimelineIndex<'a>,
Get the mutable reference of timeline(s) by the TimelineIndex.
Sourcepub fn insert_time_mark(&mut self, sec: f64, time_mark: TimeMark)
pub fn insert_time_mark(&mut self, sec: f64, time_mark: TimeMark)
Inserts an TimeMark