Locate

Trait Locate 

pub trait Locate<T>
where T: ?Sized,
{ // Required method fn locate(&self, target: &T) -> DVec3; }
Locate a point.

Required Methods

fn locate(&self, target: &T) -> DVec3

Locate self on the target

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Locate<Arc> for Focus

Source

fn locate(&self, _target: &Arc) -> DVec3

Source

impl Locate<Arc> for Origin

Source

fn locate(&self, _target: &Arc) -> DVec3

Source

impl Locate<ArcBetweenPoints> for Focus

Source

fn locate(&self, target: &ArcBetweenPoints) -> DVec3

Source

impl Locate<ArcBetweenPoints> for Origin

Source

fn locate(&self, target: &ArcBetweenPoints) -> DVec3

Source

impl Locate<Circle> for Focus

Source

fn locate(&self, _target: &Circle) -> DVec3

Source

impl Locate<Circle> for Origin

Source

fn locate(&self, _target: &Circle) -> DVec3

Source

impl Locate<Ellipse> for Focus

Source

fn locate(&self, target: &Ellipse) -> DVec3

Source

impl Locate<Ellipse> for Origin

Source

fn locate(&self, _target: &Ellipse) -> DVec3

Source

impl Locate<EllipticArc> for Focus

Source

fn locate(&self, target: &EllipticArc) -> DVec3

Source

impl Locate<EllipticArc> for Origin

Source

fn locate(&self, _target: &EllipticArc) -> DVec3

Source

impl Locate<Line> for f64

Source

fn locate(&self, target: &Line) -> DVec3

Source

impl Locate<TextItem> for Origin

Source

fn locate(&self, _target: &TextItem) -> DVec3

Source

impl<T, G> Locate<Transformed<T, G>> for Focus
where Focus: Locate<T>, G: Clone + Into<DAffine3>,

Source

fn locate(&self, target: &Transformed<T, G>) -> DVec3

Source

impl<T, G> Locate<Transformed<T, G>> for Origin
where Origin: Locate<T>, G: Clone + Into<DAffine3>,

Source

fn locate(&self, target: &Transformed<T, G>) -> DVec3

Source

impl<T> Locate<T> for DVec3
where T: ?Sized,

Source

fn locate(&self, _target: &T) -> DVec3

Implementors

Source

impl Locate<DVec3> for Centroid

Source

impl<I, G> Locate<Node<I, G>> for Centroid
where Centroid: Locate<I>, G: Clone + Into<DAffine3>,

The centroid of a tree weights every flattened leaf equally: sum each leaf’s centroid mapped through its accumulated world affine and divide by the leaf count — NOT per-child weighting. An empty tree warns and returns zero instead of producing NaNs.

Source

impl<T, G> Locate<Transformed<T, G>> for Centroid
where Centroid: Locate<T>, G: Clone + Into<DAffine3>,

Source

impl<T> Locate<T> for AabbPoint
where T: Aabb + ?Sized,

Source

impl<T> Locate<[T]> for Centroid
where Centroid: Locate<T>,