RotateTransform

Trait RotateTransform 

pub trait RotateTransform {
    // Required method
    fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Self;

    // Provided methods
    fn rotate_on_x(&mut self, angle: f64) -> &mut Self { ... }
    fn rotate_on_y(&mut self, angle: f64) -> &mut Self { ... }
    fn rotate_on_z(&mut self, angle: f64) -> &mut Self { ... }
}
Rotating operations.

This trait is automatically implemented for DVec3 and [T] where T: RotateTransform.

Required Methods

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Self

Rotate the item by a given angle about a given axis.

Provided Methods

fn rotate_on_x(&mut self, angle: f64) -> &mut Self

Rotate the item by a given angle about the X axis.

fn rotate_on_y(&mut self, angle: f64) -> &mut Self

Rotate the item by a given angle about the Y axis.

fn rotate_on_z(&mut self, angle: f64) -> &mut Self

Rotate the item by a given angle about the Z axis.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl RotateTransform for MeshItem

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut MeshItem

Source

impl RotateTransform for Arc

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Arc

Source

impl RotateTransform for ArcBetweenPoints

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut ArcBetweenPoints

Source

impl RotateTransform for Circle

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Circle

Source

impl RotateTransform for Ellipse

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Ellipse

Source

impl RotateTransform for EllipticArc

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut EllipticArc

Source

impl RotateTransform for Line

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Line

Source

impl RotateTransform for Parallelogram

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Parallelogram

Source

impl RotateTransform for Polygon

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Polygon

Source

impl RotateTransform for Rectangle

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Rectangle

Source

impl RotateTransform for RegularPolygon

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut RegularPolygon

Source

impl RotateTransform for Square

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Square

Source

impl RotateTransform for VItem

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut VItem

Source

impl RotateTransform for SvgItem

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut SvgItem

Source

impl RotateTransform for TextItem

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut TextItem

Source

impl RotateTransform for TypstText

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut TypstText

Source

impl RotateTransform for DVec3

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut DVec3

Source

impl<T> RotateTransform for [T]
where T: RotateTransform,

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut [T]

Source

impl<T> RotateTransform for VisualizeAabbItem<T>
where T: Aabb + RotateTransform,

Source

fn rotate_on_axis( &mut self, axis: DVec3, angle: f64, ) -> &mut VisualizeAabbItem<T>

Source

impl<T> RotateTransform for Vec<T>
where T: RotateTransform,

Source

fn rotate_on_axis(&mut self, axis: DVec3, angle: f64) -> &mut Vec<T>

Implementors