AlignSlice

Trait AlignSlice 

pub trait AlignSlice<T>: AsMut<[T]>{
    // Provided methods
    fn align_anchor<A>(&mut self, axis: DVec3, anchor: A) -> &mut Self
       where A: Locate<T> + Clone { ... }
    fn align(&mut self, axis: DVec3) -> &mut Self
       where T: Aabb { ... }
}
Align a slice of items

Provided Methods

fn align_anchor<A>(&mut self, axis: DVec3, anchor: A) -> &mut Self
where A: Locate<T> + Clone,

Align items’ anchors in a given axis, based on the first item.

fn align(&mut self, axis: DVec3) -> &mut Self
where T: Aabb,

Align items’ centers in a given axis, based on the first item.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors